<?php
if ( !defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly

/**
 * This class manages the screens
 *
 * @since 1.0.0
 */
if ( !class_exists( 'Monoedge_Admin_Screens' ) ) {

    class Monoedge_Admin_Screens {
        public function __construct() {
            $this->monoedge_admin_screens_config();
            if ( !wp_doing_ajax() ) {
                if ( is_admin() ) {
                    $this->monoedge_admin_screens_menu();
                }
            }
            else{
                
                add_action( 'wp_ajax_monoedge_form_sign_up', array( $this, 'monoedge_forms_action' ) );
                add_action( 'wp_ajax_monoedge_form_login', array( $this, 'monoedge_forms_action' ) );
                add_action( 'wp_ajax_monoedge_form_forgot_password', array( $this, 'monoedge_forms_action' ) );
                add_action( 'wp_ajax_monoedge_form_disconnect', array( $this, 'monoedge_forms_action' ) );

                add_action( 'wp_ajax_monoedge_set_option', array( $this, 'monoedge_set_option' ) );
                add_action( 'wp_ajax_monoedge_chosen_options', array( $this, 'monoedge_chosen_options' ) );
                add_action( 'wp_ajax_monoedge_setup_options_remove', array( $this, 'monoedge_setup_options_remove' ) );

                add_action( 'wp_ajax_monoedge_get_updated_urls', array( $this, 'monoedge_get_updated_urls' ) );

                add_action( 'wp_ajax_monoedge_load_screen', array( $this, 'monoedge_load_screen' ) );

                add_action( 'wp_ajax_monoedge_tracking', array( $this, 'monoedge_tracking' ) );

                add_action( 'wp_ajax_monoedge_create_demo_page', array( $this, 'monoedge_create_demo_page' ) );
            }
        }
        public function monoedge_admin_screens_config(){
            if ( class_exists( 'Monoedge_Utils' ) ) {
                Monoedge_Utils::monoedge_require_once( MONOEDGE_PLUGIN_DIR . '/includes/admin/helper/class-monoedge-helper-screens.php' );
            }
        }
        public function monoedge_admin_screens_menu(){
            add_action( 'admin_menu', array( $this, 'monoedge_wordpress_add_menu_options' ) );
        }

        /*
          * Actions perform at loading of admin menu
        */
        public function monoedge_wordpress_add_menu_options() {
            // $title = _e( 'MonoEdge',  'monoedge-restaurant-system' );
            $title = 'MonoEdge';
            if ( current_user_can( 'manage_options' ) ) {
                add_menu_page( 'MonoEdge', $title, 'manage_options', 'monoedge-overview', array(
                    $this,
                    'monoedge_wordpress_add_menu_include'
                ), MONOEDGE_PLUGIN_URL . 'assets/images/MONOEDGE-icon.svg', 90 );

                // add_submenu_page( 'monoedge-overview', _e( 'Overview', 'monoedge-restaurant-system' ), _e( 'Overview', 'monoedge-restaurant-system' ), 'manage_options', 'monoedge-overview', array(
                add_submenu_page( 'monoedge-overview', 'Overview', 'Overview', 'manage_options', 'monoedge-overview', array(
                    $this,
                    'monoedge_wordpress_add_menu_include'
                ) );
                // add_submenu_page( 'monoedge-overview', _e( 'Settings', 'monoedge-restaurant-system' ), _e( 'Settings', 'monoedge-restaurant-system' ), 'manage_options', 'monoedge-settings', array(
                add_submenu_page( 'monoedge-overview', 'Settings', 'Settings', 'manage_options', 'monoedge-settings', array(
                    $this,
                    'monoedge_wordpress_add_menu_include'
                ) );
            }
        }
        //_e( $extra_todo['title'], 'monoedge-restaurant-system' );

        /*
         * Actions perform on loading of left menu or settings pages
         */
        public function monoedge_wordpress_add_menu_include() {
            // $pages = array( 'overview', 'settings', 'screens', 'html' );
            $pages = array( 'overview', 'screens', 'settings' );
            $screen = get_current_screen();
            foreach ( $pages as $page ) {
                if ( Monoedge_Utils::monoedge_url_ends_with( $screen->base, $page ) !== false ) {
                    // if ( in_array( $page, array( 'overview', 'settings', 'screens', 'html' ) ) ) {
                    if ( in_array( $page, array( 'overview', 'settings' ) ) ) {
                        Monoedge_Utils::$_MONOEDGE->get_and_update_user_data();
                        // Monoedge_Utils::$_MONOEDGE->load_user_data();
                        // Monoedge_Utils::monoedge_set_default_app_options( false, 'add_menu' );
                        // Monoedge_Utils::monoedge_custom_css_check_and_set_defaults( Monoedge_Utils::$_MONOEDGE->custom_css );
                        require(MONOEDGE_PLUGIN_DIR . 'includes/admin/' . $page . '/class-monoedge-screen-' . $page . '.php');
                    }
                    break;
                }
            }
        }

        public function monoedge_load_screen() {
            
            // Monoedge_Utils::write_log("monoedge_load_screen");

            // Nonce validation
            if (!isset($_POST['ajax_nonce']) || !wp_verify_nonce($_POST['ajax_nonce'], 'monoedge-nonce')) {
                $response = array('status' => 'error', 'message' => 'Nonce verification failed');
                wp_send_json_error($response);
                wp_die();
            }

            $action = isset( $_POST[ 'action' ] ) ? $_POST[ 'action' ] : '';
            $response = array( 'action' => $action );
            
            // Monoedge_Utils::write_log("action");
            // Monoedge_Utils::write_log($action);
            // Monoedge_Utils::write_log("response");
            // Monoedge_Utils::write_log($response);

            if ( Monoedge_Utils::monoedge_capabilities_check() ) {
                Monoedge_Utils::monoedge_capabilities_check_failed( $response );
            }

            $screen = isset( $_POST[ 'data' ], $_POST[ 'data' ][ 'screen' ] ) ? $_POST[ 'data' ][ 'screen' ] : '';

            if ( $action !== 'monoedge_load_screen' && !empty( $screen )  ) {
                $response[ 'status' ] = 'success';
                echo wp_json_encode( $response );
                exit();
            }

            if( $screen === 'overview_authenticate' ){
                ob_start();
                Monoedge_Utils::monoedge_require_once( __DIR__ . '/overview/overview_top_bar.php' );
                $_POST['screen_sign_up'] = 'true';
                Monoedge_Utils::monoedge_require_once( __DIR__ . '/overview/overview_authenticate.php' );
                $response[ 'screen' ] = ob_get_clean();
                $response[ 'empty' ] = 'true';
            }


            $response[ 'POST' ] = $_POST;
            $response[ 'status' ] = 'success';
            echo wp_json_encode( $response );
            exit();

        }

        public function monoedge_forms_action() {
            
            // Nonce validation
            if (!isset($_POST['ajax_nonce']) || !wp_verify_nonce($_POST['ajax_nonce'], 'monoedge-nonce')) {
                $response = array('status' => 'error', 'message' => 'Nonce verification failed');
                wp_send_json_error($response);
                wp_die();
            }
            
            global $allowed_html;

            $errors = array();
            $action = isset( $_POST[ 'action' ] ) ? str_replace( 'monoedge_form_', '', $_POST[ 'action' ] ) : '';

            $data = $_POST[ 'data' ];
            parse_str( $data, $data );

            $_POST = array( 'action' => $action );
            foreach ( $data as $key => $d ) {
                $_POST[ $key ] = $d;
            }
            $response = array( 'action' => $action );

            // if ( in_array( $action, array( 'forgot_password', 'login', 'sign_up' ) ) ) {
            if ( in_array( $action, array( 'login', 'sign_up' ) ) ) {
                if ( $this->monoedge_security_check() ) {
                    $this->monoedge_security_check_failed( $response );
                }

                $response[ 'data' ] = $data;

                $validate_fields = $this->monoedge_validate_fields( $action, $_POST );
                if ( !empty( $validate_fields ) ) {
                    $errors = $validate_fields;
                } else {
                    $errors = $this->monoedge_validate_form( $action );
                }
                if( !empty( $errors ) ){
                    $response[ 'errors' ] = $errors;
                }
                if ( empty( $errors ) ) {
                    $response[ 'status' ] = 'success';
                    $response[ 'post' ] = $_POST;
                    $response[ 'logged_in' ] = Monoedge_Utils::$_MONOEDGE->is_authenticated();
                    
                    Monoedge_Utils::monoedge_set_default_app_options( false, $action);
                    $monoedge_wordpress_options = Monoedge_Utils::monoedge_wp_options_data('true');
                    ob_start();
                    if ( $action == 'login' ){
                        Monoedge_Utils::$_MONOEDGE->get_and_update_user_data();
                        Monoedge_Utils::$_MONOEDGE->load_user_data();

                        $is_update = Monoedge_Utils::monoedge_get_from_wordpress_options( 'is_update', '' );
                        if( $is_update ){
                            Monoedge_Utils::monoedge_add_to_wordpress_options( 'is_update', false );
                            Monoedge_Helper_Screens::set_default_setup_options();
                            $response[ 'action' ] = 'redirect';
                            $response[ 'screen_url' ] = admin_url() . 'admin.php?page=monoedge-overview';
                        }  else{

                            Monoedge_Utils::monoedge_require_once( __DIR__ . '/overview/overview_screen_options.php' );
                            Monoedge_Utils::monoedge_add_to_wordpress_options( $action, false );

                            $screen_output = Monoedge_get_screen_sequence( $action );
                            $response[ 'html' ] = $screen_output['output'];
                            if( empty( $response[ 'html' ] ) ){
                                $response[ 'action' ] = 'redirect';
                                $response[ 'screen_url' ] = admin_url() . 'admin.php?page=monoedge-overview';
                            }
                            else{
                                if( $screen_output['extra'] === 'empty' ){
                                    $response[ 'empty' ] = 'true';
                                }
                                // echo $response[ 'html' ];
                                // echo esc_html( $response[ 'html' ] );
                                echo wp_kses( $response[ 'html' ],  $allowed_html );
                            }
                        }

                    } else if ( $action !== 'sign_up' ){
                        Monoedge_Utils::monoedge_require_once( __DIR__ . '/overview/overview_authenticate.php' );
                        $response[ 'empty' ] = 'true';
                    } else {
                        Monoedge_Utils::monoedge_require_once( __DIR__ . '/overview/overview_authenticate.php' );
                        $response[ 'empty' ] = 'true';
                    }

                    $response[ 'screen' ] = ob_get_clean();

                }
            } else if ( $action === 'disconnect' ) {
                if ( $this->monoedge_security_check() ) {
                    $this->monoedge_security_check_failed( $response );
                }
                // delete_option( 'monoedge_connection_type' );
                Monoedge_Utils::$_MONOEDGE->remove_user_data();
            } else {
                if ( Monoedge_Utils::monoedge_capabilities_check() ) {
                    Monoedge_Utils::monoedge_capabilities_check_failed( $response );
                }
            }

            $response[ 'POST' ] = $_POST;
            echo wp_json_encode( $response );
            exit();
        }
        public function monoedge_set_option() {

            // Nonce validation
            if (!isset($_POST['ajax_nonce']) || !wp_verify_nonce($_POST['ajax_nonce'], 'monoedge-nonce')) {
                $response = array('status' => 'error', 'message' => 'Nonce verification failed');
                wp_send_json_error($response);
                wp_die();
            }

            $errors = array();
            $action = isset( $_POST[ 'action' ] ) ? $_POST[ 'action' ] : '';

            $data = $_POST[ 'data' ];
            $response = array( 'action' => $action );

            if ( Monoedge_Utils::monoedge_capabilities_check() ) {
                Monoedge_Utils::monoedge_capabilities_check_failed( $response );
            }

            if ( $action === 'monoedge_set_option' ) {
                Monoedge_Utils::monoedge_add_to_wordpress_options( (string)$data[ 'option_name' ], (string)$data[ 'option_value' ] );


                if( isset( $data['screen'] ) ){
                    if( $data[ 'screen' ] === 'overview' ){
                        $response[ 'action' ] = 'redirect';
                        $response[ 'screen_url' ] = admin_url() . 'admin.php?page=monoedge-overview';

                    } else{
                        $response[ 'action' ] = $data[ 'screen' ];
                    }
                }
                $response[ 'status' ] = 'success';
                $response[ $data['option_name'] ] = Monoedge_Utils::monoedge_get_from_wordpress_options( (string)$data[ 'option_name' ], '', 'true' );

            }

            echo wp_json_encode( $response );
            exit();
        }
        public function monoedge_chosen_options() {

            // Nonce validation
            if (!isset($_POST['ajax_nonce']) || !wp_verify_nonce($_POST['ajax_nonce'], 'monoedge-nonce')) {
                $response = array('status' => 'error', 'message' => 'Nonce verification failed');
                wp_send_json_error($response);
                wp_die();
            }

            $errors = array();
            $action = isset( $_POST[ 'action' ] ) ? $_POST[ 'action' ] : '';

            $data = $_POST[ 'data' ];
            $response = array( 'action' => $action );
            if ( Monoedge_Utils::monoedge_capabilities_check() ) {
                Monoedge_Utils::monoedge_capabilities_check_failed( $response );
            }
            if ( $action === 'monoedge_chosen_options' ) {
                $chosen_options = array();
                // $chosen_options_status = array();
                foreach ( $data as $option_name => $option ) {
                    if ( $option === 'true' ) {
                        $_extra_options = Monoedge_Helper_Screens::get_todo_options_of_extra_option( $option_name );
                        if(!empty( $_extra_options) && is_array( $_extra_options)){
                            foreach ( $_extra_options as $_extra_opt_key => $val ) {
                                $chosen_options[] = $_extra_opt_key;
                                // $chosen_options_status[$_extra_opt_key] = false;
                            }
                        } else{
                            $chosen_options[] = $option_name;
                        }
                    }

                }
                Monoedge_Utils::monoedge_add_to_wordpress_options( 'setup_options', $chosen_options );
                // Monoedge_Utils::monoedge_add_to_wordpress_options( 'setup_options_status', $chosen_options_status );

                $response[ 'status' ] = 'success';
                $response[ 'data' ] = $_POST[ 'data' ];
            }

            echo wp_json_encode( $response );
            exit();
        }
        public function monoedge_setup_options_remove() {
            
            // Nonce validation
            if (!isset($_POST['ajax_nonce']) || !wp_verify_nonce($_POST['ajax_nonce'], 'monoedge-nonce')) {
                $response = array('status' => 'error', 'message' => 'Nonce verification failed');
                wp_send_json_error($response);
                wp_die();
            }

            $errors = array();
            $action = isset( $_POST[ 'action' ] ) ? $_POST[ 'action' ] : '';

            $data = $_POST[ 'data' ];
            $response = array( 'action' => $action );

            if ( Monoedge_Utils::monoedge_capabilities_check() ) {
                Monoedge_Utils::monoedge_capabilities_check_failed( $response );
            }

            if ( $action === 'monoedge_setup_options_remove' && isset( $data['option'] )  ) {
                if( $data[ 'option' ] === 'enroll_partner_program' ){
                    Monoedge_Utils::monoedge_add_to_wordpress_options( 'partner_program_dismiss', 'yes' );
                }else{
                    $chosen_options = Monoedge_Utils::monoedge_get_from_wordpress_options( 'setup_options', array() );
                    foreach ( $chosen_options as $idx => $option ) {
                        if ( $data[ 'option' ] === $option ) {
                            unset( $chosen_options[ $idx ] );
                        }

                    }
                    Monoedge_Utils::monoedge_add_to_wordpress_options( 'setup_options', $chosen_options );
                }

                $response[ 'status' ] = 'success';
                $response[ 'data' ] = $_POST[ 'data' ];
            }

            echo wp_json_encode( $response );
            exit();
        }
        public function monoedge_get_updated_urls(){ // event: changed location
            
            // Nonce validation
            if (!isset($_POST['ajax_nonce']) || !wp_verify_nonce($_POST['ajax_nonce'], 'monoedge-nonce')) {
                $response = array('status' => 'error', 'message' => 'Nonce verification failed');
                wp_send_json_error($response);
                wp_die();
            }

            $action = isset( $_POST[ 'action' ] ) ? $_POST[ 'action' ] : '';

            $response = array( 'action' => $action );

            if ( Monoedge_Utils::monoedge_capabilities_check() ) {
                Monoedge_Utils::monoedge_capabilities_check_failed( $response );
            }

            if ( $action === 'monoedge_get_updated_urls' ) {
                $data = $_POST[ 'data' ];
                $location_uuid = isset( $data[ 'location_uuid' ] ) ? (string)$data[ 'location_uuid' ] : '';

                $monoedge_wordpress_options = Monoedge_Utils::monoedge_wp_options_data();
                $monoedge_wordpress_options->{'app_options'}[ Monoedge_Utils::$_MONOEDGE->user['user']['id'] ][ 'default_location' ] = $location_uuid;
                Monoedge_Utils::monoedge_database_option_operation( 'update', 'monoedge_wordpress_options', $monoedge_wordpress_options );

                $response[ 'status' ] = 'success';
                $response[ 'location' ] = $location_uuid;
                $location = Monoedge_Utils::get_location_data_by_location_uuid( $location_uuid );
                $response[ 'todo' ] = Monoedge_Helper_Screens::generate_todo_list( $location );
                // $response[ 'admin_url' ] = Monoedge_Utils::$_MONOEDGE->get_monoedge_token() . '&r=app.admin.setup&acid=' . $location->account_id;
                $response[ 'admin_url' ] = Monoedge_Utils::$_MONOEDGE->get_monoedge_token() . '/home/setup/step1/';

            }

            echo wp_json_encode( $response );
            exit();
        }

        public function monoedge_security_check_failed( $response ) {
            $response[ 'status' ] = 'error';
            $response[ 'msg' ] = 'Access restricted, security check failed!';
            echo wp_json_encode( $response );
            exit();
        }

        public function monoedge_security_check() {
            $tmp1 = ! empty( $_POST[ 'action' ]);
            $tmp2 = current_user_can( 'manage_options' );
            $tmp3 = isset( $_POST[ '_wpnonce' ] );
            $tmp4 = wp_verify_nonce( $_POST[ '_wpnonce' ], 'monoedge-nonce' );
            $tmp5 = (!(!empty( $_POST[ 'action' ] ) && current_user_can( 'manage_options' ) && isset( $_POST[ '_wpnonce' ] ) && wp_verify_nonce( $_POST[ '_wpnonce' ], 'monoedge-nonce' )));
            return (!(!empty( $_POST[ 'action' ] ) && current_user_can( 'manage_options' ) && isset( $_POST[ '_wpnonce' ] ) && wp_verify_nonce( $_POST[ '_wpnonce' ], 'monoedge-nonce' )));
        }

        public function monoedge_validate_form( $mode ) {
            $errors = array();

            // if( $mode === 'login' ){  // "login", "forgot_password", 
            //     $connection_type = isset( $_POST[ 'monoedge_connection_type' ] ) ? $_POST[ 'monoedge_connection_type' ] : '';
            //     if( !empty( $connection_type ) ){
            //         update_option( 'monoedge_connection_type', $connection_type );
            //     }
            // }
            // $get_connection_type = get_option( 'monoedge_connection_type', '' );  // "production" , "staging", "register"
            // $response_body = Monoedge_Utils::monoedge_mor_remote_call( ( $get_connection_type === 'staging' ? MONOEDGE_STAGING_API_URL : MONOEDGE_API_URL ), $mode );
            $response_body = Monoedge_Utils::monoedge_remote_call( ( MONOEDGE_API_URL ), $mode );   //////////////////////////////////// need ot fix

            $response[ 'response_body' ] = $response_body;
            if ( isset( $response_body->error ) ) {
                $errors[ "form" ] = $response_body->error;
            } else if ( $mode == 'login' ) {
                if (isset( $response_body['token'] )) {

                    Monoedge_Utils::$_MONOEDGE->save_user_data( array(
                        // 'user' => $response_body->user,
                        // 'auth_domain' => $response_body->domain,
                        // 'auth_token' => $response_body->token,
                        'api_token' => $response_body['token']
                    ) );
                    Monoedge_Utils::$_MONOEDGE->load_user_data();
                    
                    $response_body = Monoedge_Utils::monoedge_remote_call( ( MONOEDGE_API_URL ), 'get_user_from_server' );   //////////////////////////////////// need ot fix
                    if (isset( $response_body->user )) {

                        Monoedge_Utils::$_MONOEDGE->save_user_data( array(
                            'user' => $response_body->user,
                        ) );
                        Monoedge_Utils::$_MONOEDGE->load_user_data();
                    }

                }
            } else if ( $mode !== 'sign_up' ) {
                $errors = $this->monoedge_validate_form( 'login' );
            } else if ( $mode !== 'forgot_password' ) {

            }

            return $errors;
        }

        public function monoedge_validate_fields( $mode, $_post ) {

            // Nonce validation
            if (!isset($_post['_wpnonce']) || !wp_verify_nonce($_post['_wpnonce'], 'monoedge-nonce')) {
                $response = array('status' => 'error', 'message' => 'Nonce verification failed');
                wp_send_json_error($response);
                wp_die();
            }
            
            $fields = array(
                "login" => array( "email", "password" ),
                "sign_up" => array( "email", "password", "restaurant_name", "first_name", "last_name" ),
                "forgot_password" => array( "email" ),
            );
            $fields = $fields[ $mode ];
            $errors = array();
            foreach ( $fields as $field ) {
                if ( !isset( $_post[ $field ] ) || empty( $_post[ $field ] ) ) {
                    $errors[ $field ] = "Please fill in the " .$this->monoedge_field_to_label( $field );
                } elseif ( $field === "email" && !is_email( $_post[ $field ] ) ) {
                    $errors[ $field ] = "The Email Address you inserted is invalid!";
                }
            }

            return $errors;
        }

        public function monoedge_field_to_label( $field ) {
            switch ( $field ) {
                case 'email':
                    return __( 'Email', 'monoedge-restaurant-system' );

                case 'password':
                    return __( 'Password', 'monoedge-restaurant-system' );

                case 'restaurant_name':
                    return __( 'Restaurant name', 'monoedge-restaurant-system' );

                case 'first_name':
                    return __( 'First name', 'monoedge-restaurant-system' );

                case 'last_name':
                    return __( 'Last name', 'monoedge-restaurant-system' );

                default:
                    return ucwords( str_replace( "_", " ", $field ) );
            }

        }

        public function monoedge_tracking() {
            
            // Nonce validation
            if (!isset($_POST['ajax_nonce']) || !wp_verify_nonce($_POST['ajax_nonce'], 'monoedge-nonce')) {
                $response = array('status' => 'error', 'message' => 'Nonce verification failed');
                wp_send_json_error($response);
                wp_die();
            }
            
            $action = isset( $_POST[ 'action' ] ) ? $_POST[ 'action' ] : '';
            $data = $_POST[ 'data' ];
            $response = array( 'action' => $action );

            if ( Monoedge_Utils::monoedge_capabilities_check() ) {
                Monoedge_Utils::monoedge_capabilities_check_failed( $response );
            }

            if ( $action === 'monoedge_tracking' ) {
                if ( $data['type'] === 'todo' ) {
                    // $response['data'] = Monoedge_Utils::monoedge_tracking_send( $data );
                    $monoedge_wordpress_options = Monoedge_Utils::monoedge_wp_options_data();
                    if ( ! (isset( $monoedge_wordpress_options->{'app_options'}[ $data['location_uuid'] ] ))){
                        $monoedge_wordpress_options->{'app_options'}[ $data['location_uuid'] ] = array();
                    }
                    if ( ! (isset( $monoedge_wordpress_options->{'app_options'}[ $data['location_uuid'] ][ 'setup_options_status' ]))){
                        $monoedge_wordpress_options->{'app_options'}[ $data['location_uuid'] ][ 'setup_options_status' ] = array();
                    }
                    if ( ! (isset( $monoedge_wordpress_options->{'app_options'}[ $data['location_uuid'] ][ 'setup_options_status' ][ $action ]))){
                        $monoedge_wordpress_options->{'app_options'}[ $data['location_uuid'] ][ 'setup_options_status' ][ $data["id"] ] = "done";
                    }
                    Monoedge_Utils::monoedge_database_option_operation( 'update', 'monoedge_wordpress_options', $monoedge_wordpress_options );
                }
            }
            // echo wp_json_encode( $response );
            // exit();
        }

        public function monoedge_create_demo_page() {
            
            // Nonce validation
            if (!isset($_POST['ajax_nonce']) || !wp_verify_nonce($_POST['ajax_nonce'], 'monoedge-nonce')) {
                $response = array('status' => 'error', 'message' => 'Nonce verification failed');
                wp_send_json_error($response);
                wp_die();
            }

            $action = isset( $_POST[ 'action' ] ) ? $_POST[ 'action' ] : '';
            $data = $_POST[ 'data' ];
            $response = array( 'action' => $action );

            if ( Monoedge_Utils::monoedge_capabilities_check() ) {
                Monoedge_Utils::monoedge_capabilities_check_failed( $response );
            }

            if ( $action === 'monoedge_create_demo_page' ) {
                Monoedge_Helper_Screens::create_demo_page();
                $response['url'] = Monoedge_Helper_Screens::get_demo_page_edit_url();

            }
            echo wp_json_encode( $response );
            exit();
        }

    }

    new Monoedge_Admin_Screens();
}