<?php
if ( !defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly
?>
<?php
// Output screens following a predefined sequence
// This sequence can be altered: modify the order or add other screens
function Monoedge_get_screen_sequence( $action ){
    
    // Nonce velification
    if (!isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'monoedge-nonce')) {
        exit('Nonce verification failed');
    }

    $screens = array(
        'share_usage_data',
        'setup_options',
        'partner_program',
        'alternative_flow',
    );
    $extra = '';
    $screen_sequence = array();
    $user = Monoedge_Helper_Screens::get_user();
    $location = Monoedge_Helper_Screens::get_default_location();

    $share_usage = empty( Monoedge_Utils::Monoedge_get_from_wordpress_options( 'share_usage_data', '' ) );
    $setup_options = empty( Monoedge_Utils::Monoedge_get_from_wordpress_options( 'setup_options', '' ) );

    $partner_screen = (isset( $_POST[ 'partner_program' ] ) && $_POST[ 'partner_program' ] === 'true');
    $partner_program = Monoedge_Utils::Monoedge_get_from_wordpress_options( 'partner_program', '' );
    $partner_program = ( $partner_screen ) ? empty( $partner_program ) : false;

    $overview_redirect_url = admin_url() . 'admin.php?page=monoedge-overview';


    if( $action === 'update' ){
        $screen_sequence = array(
            'share_usage_data' => array(
                'cssClass' => ' screen-active ',
                'next' => 'overview'
            )
        );

    } else {
        $screen_active = false;
        $screen_alternative = false;

        $setup_options = $action === 'sign_up' ? true : $setup_options;

        if( $share_usage ){
            $screen_sequence [ 'share_usage_data' ] = array(
                'cssClass' => (!$screen_active) ? ' screen-active ' : '',
                'next' => 'screen_options'
            );
            $screen_active = true;
            if( !$setup_options ){
                $screen_sequence [ 'share_usage_data' ]['next'] = 'redirect';
                $screen_sequence [ 'share_usage_data' ]['url'] = $overview_redirect_url;
            }
        }
        if( $setup_options ){
            $screen_sequence [ 'setup_options' ] = array(
                'cssClass' => (!$screen_active) ? ' screen-active ' : '',
                'next' => 'screen_partner_program'
            );
            if( !$screen_active ){
                $extra = 'empty';
            }
            $screen_active = true;
            $setup_brand_location = Monoedge_Helper_Screens::is_done_setup_brand_location( $location );
            $screen_alternative = true;
            if ( $partner_program && is_null( $location->partner_account_id ) ) {
                $screen_sequence [ 'partner_program' ] = array(
                    'cssClass' => (!$screen_active) ? ' screen-active ' : '',
                    'next' => 'screen_alternative_flow'
                );
                if( $setup_brand_location ){
                    $screen_alternative = false;
                    $screen_sequence [ 'partner_program' ][ 'next' ] = 'redirect';
                    $screen_sequence [ 'partner_program' ][ 'url' ] = $overview_redirect_url;
                }

            }
            else{
                if ( $setup_brand_location ) {
                    $screen_sequence [ 'setup_options' ][ 'next' ] = 'redirect';
                    $screen_sequence [ 'setup_options' ][ 'url' ] = $overview_redirect_url;
                }
                else{
                    $screen_sequence [ 'setup_options' ][ 'next' ] = 'screen_alternative_flow';
                }
            }
        }
        if( $screen_alternative ){
            $screen_sequence [ 'alternative_flow' ] = array(
                'cssClass' => (!$screen_active) ? ' screen-active ' : '',
                'next' => ''
            );
        }
    }

    return array( 'output' => screen_output_sequence( $screen_sequence ), 'extra' => $extra );
}


function screen_output_sequence( $screen_sequence = array() ){
    ob_start();
    if( empty( $screen_sequence ) ){
        return ob_get_clean();
    }
    $Monoedge_wordpress_options = Monoedge_Utils::Monoedge_wp_options_data();
    foreach ( $screen_sequence as $screen_name => $screen_options){
        $method = 'Monoedge_output_screen_' . $screen_name;
        if( function_exists( $method ) ){
            call_user_func( $method, $screen_options );
        }
    }
    $screens_html = ob_get_clean();
    return $screens_html;
}
?>

<?php
// Screen Share Usage Data
function Monoedge_output_screen_share_usage_data( $screen_options ) {
    ?>
    <div id="screen_data_usage" class="screen <?php echo esc_attr( $screen_options[ 'cssClass' ] ); ?> monoedge-section-overlay">
    <div class="monoedge-section-content monoedge-w-544 monoedge-white-back flx-col flx-align-center monoedge-spacing-v1">
        <div class="section-title"><?php esc_attr_e( 'Help us improve MonoEdge', 'monoedge-restaurant-system' ); ?></div>
        <div class="monoedge-line-spacer"></div>
        <div class="monoedge-overlay-text">
            <span><?php esc_attr_e( 'Become a super contributor by opting in to share non-sensitive plugin data.', 'monoedge-restaurant-system' ); ?> <a href="https://langing.as3.monoedge.ai/top/resources/pp" target="_blank" rel="noreferrer"><?php esc_attr_e( 'Learn more', 'monoedge-restaurant-system' ); ?></a></span>
        </div>
        <div class="monoedge-column monoedge-col-h-right ">
            <?php
            $next_screen = isset( $screen_options[ 'next' ] ) ? $screen_options[ 'next' ] : '';
            $next_url = isset( $screen_options[ 'url' ] ) ? $screen_options[ 'url' ] : '';
            ?>
            <a href="" class="monoedge-link monoedge-button-action" data-id="<?php echo esc_attr( $next_screen ); ?>" data-id_url="<?php echo esc_url( $next_url ); ?>" data-value="no" data-action="monoedge_set_option" data-option="share_usage_data"><?php esc_attr_e( 'Don’t share', 'monoedge-restaurant-system' ); ?></a>
            <a href="" class="monoedge-button monoedge-button-action" data-id="<?php echo esc_attr( $next_screen ); ?>" data-id_url="<?php echo esc_url( $next_url ); ?>" data-value="yes" data-action="monoedge_set_option" data-option="share_usage_data"><?php esc_attr_e( 'Share usage data', 'monoedge-restaurant-system' ); ?></a>
        </div>
    </div>
</div>
    <?php
}

?>

<?php
// Screen Setup Options
function Monoedge_output_screen_setup_options( $screen_options ){
?>
<div id="screen_options" class="screen <?php echo esc_attr( $screen_options[ 'cssClass' ] ); ?> monoedge-section monoedge-white-back flx-col" style="align-self:center; margin-top: 24px;">
    <div class="section-title"><?php esc_attr_e( 'Select what options you want to setup', 'monoedge-restaurant-system' ); ?></div>
    <div class="section-subtitle"><?php esc_attr_e( 'Choose the features that you need', 'monoedge-restaurant-system' ); ?></div>
    <div class="monoedge-list flx-col">
         <div class="monoedge-form-field list flx-row form-footer">
            <?php
            $Monoedge_wordpress_options = Monoedge_Utils::Monoedge_wp_options_data();
            $user_id = Monoedge_Utils::monoedge_get_user()->id;
            foreach ( Monoedge_Helper_Screens::get_extra_options() as $extra_option_name => $extra_option ) {
                $display = Monoedge_Helper_Screens::kickstart_and_autopilot_display_check_setup( $extra_option_name );
                if( $extra_option_name !== 'enroll_partner_program' && $display ){
                    if ( !isset( $Monoedge_wordpress_options->app_options[ $user_id ][ $extra_option_name ] ) ) {
                        $preselected = ((isset( $extra_option[ 'preselected' ] ) && $extra_option[ 'preselected' ] === 'true') ? 'checked' : '');
                    } else {
                        $preselected = ($Monoedge_wordpress_options->app_options[ $user_id ][ $extra_option_name ] === 'true' ? 'checked' : '');
                    }
                ?>

                <div class="monoedge-filed-checkbox">
                    <input id="<?php echo esc_attr( $extra_option_name ); ?>" name="<?php echo esc_attr( $extra_option_name ); ?>" type="checkbox" <?php echo esc_attr( $preselected ); ?> data-tracking="<?php echo esc_attr( $extra_option[ 'title' ] ); ?>">
                    <label for="<?php echo esc_attr( $extra_option_name ); ?>"><?php echo esc_attr( $extra_option[ 'title' ] ); ?></label>
                    <?php
                    if ( isset( $extra_option[ 'paid' ] ) && $extra_option[ 'paid' ] === 'true' ) {
                        ?>
                        <div class="monoedge-tag"><?php esc_attr_e( 'Premium', 'monoedge-restaurant-system' ); ?></div>
                        <?php
                    }
                    ?>
                </div>
                <?php
                }
            }
            ?>
            <div class="monoedge-filed-submit">
                <?php
                $next_screen = isset( $screen_options[ 'next' ] ) ? $screen_options[ 'next' ] : '';
                $next_url = isset( $screen_options[ 'url' ] ) ? $screen_options[ 'url' ] : '';
                ?>
                <div class="monoedge-button monoedge-button-action" data-id="<?php echo esc_attr( $next_screen ); ?>" data-id_url="<?php echo esc_url( $next_url ); ?>" data-action="monoedge_chosen_options"><?php esc_attr_e( 'Continue', 'monoedge-restaurant-system' ); ?></div>
            </div>
        </div>
    </div>
</div>
<?php
}
?>

<?php
// Screen Partner Program
function Monoedge_output_screen_partner_program( $screen_options ) {
    ?>

    <div id="screen_partner_program" class="screen <?php echo esc_attr( $screen_options[ 'cssClass' ] ); ?> monoedge-section-overlay">
    <div class="monoedge-section-content monoedge-w-544 monoedge-white-back flx-col flx-align-center monoedge-spacing-v1">
        <div class="section-title"><?php esc_attr_e( 'Join Partner Program and earn', 'monoedge-restaurant-system' ); ?></div>
        <div class="monoedge-line-spacer"></div>
        <div class="monoedge-image">
            <img src="<?php echo esc_url( MONOEDGE_PLUGIN_URL ) . 'includes/admin/assets/images/illustration.png' ?>" width="221" height="130px" alt="">
        </div>
        <div class="monoedge-overlay-text">
            <span><?php esc_attr_e( 'Restaurant that you create for others can bring you additional revenue if you become a partner.', 'monoedge-restaurant-system' ); ?></span>
        </div>
        <div class="monoedge-overlay-text">
            <span><?php esc_attr_e( 'Are you interested in being part of the Partner Program?', 'monoedge-restaurant-system' ); ?></span>
        </div>
        <div class="monoedge-column monoedge-col-h-right monoedge-col-spacing-top">
            <?php
            $next_screen = isset( $screen_options[ 'next' ] ) ? $screen_options[ 'next' ] : '';
            $next_url = isset( $screen_options[ 'url' ] ) ? $screen_options[ 'url' ] : '';
            ?>
            <a href="" class="monoedge-link monoedge-button-action" data-id="<?php echo esc_attr( $next_screen ); ?>" data-id_url="<?php echo esc_url( $next_url ); ?>" data-value="no" data-action="monoedge_set_option" data-option="partner_program"><?php esc_attr_e( 'Not now', 'monoedge-restaurant-system' ); ?></a>
            <a href="" class="monoedge-button monoedge-button-action" data-id="<?php echo esc_attr( $next_screen ); ?>" data-id_url="<?php echo esc_url( $next_url ); ?>" data-value="yes" data-action="monoedge_set_option" data-option="partner_program"><?php esc_attr_e( 'Yes, I\'m interested', 'monoedge-restaurant-system' ); ?></a>
        </div>
    </div>
</div>
<?php
}
?>

<?php
// Screen Alternative Flow
function Monoedge_output_screen_alternative_flow( $screen_options ){
?>
<div id="screen_alternative_flow" class="monoedge-section-content screen <?php echo esc_attr( $screen_options[ 'cssClass' ] ); ?> monoedge-w-544 monoedge-white-back flx-col flx-align-center monoedge-spacing-v1">
    <div class="section-title"><?php esc_attr_e( 'Admin setup', 'monoedge-restaurant-system' ); ?></div>
    <div class="monoedge-overlay-text light" style="margin-top: 8px;">
        <span><?php esc_attr_e( 'You will now need to go to MonoEdge Admin in order to setup your restaurant profile. After finishing the setup you can come back and add the widgets on your website.', 'monoedge-restaurant-system' ); ?></span>
    </div>
    <div class="monoedge-column monoedge-col-h-center monoedge-col-spacing-top" style="margin-bottom: 16px;">
        <a href="<?php echo esc_attr( Monoedge_Utils::$_MONOEDGE->get_monoedge_token() ) . '/home/setup/step1/'; ?>" class="monoedge-button " data-overview="<?php echo esc_attr( Monoedge_Utils::$_MONOEDGE->get_monoedge_token() ) . '/home/setup/step1/'; ?>"   target="_blank" rel="noreferrer"><span class="icon"></span><?php esc_attr_e( 'Start the setup', 'monoedge-restaurant-system' ); ?></a>
    </div>
</div>
<?php
}
?>