<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

/**
 * This class contains some utilities needed for the plugin.
 *
 * @since 1.0.0
 */
if ( ! class_exists( 'Monoedge_Utils' ) ) {

	class Monoedge_Utils {

        
	    private function __construct() {
            print_r("          [Monoedge_Utils] run");
        }

		public static $_MONOEDGE = null;
		public static $_monoedge_user_data = null;  // monoedge_user_data
		public static $_wp_options_data = null;  // monoedge_wordpress_options
		public static $_monoedge_option_complete = null; // monoedge_option_complete


		public static function monoedge_save_user_data( $args ) {
			self::$_MONOEDGE->save_user_data( $args );
		}


		public static function monoedge_remote_call( $url, $mode ) {

			switch ( $mode ) {
				case 'login':
                    
                    // Nonce velification
                    if (!isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'monoedge-nonce')) {
                        exit('Nonce verification failed');
                    }
					$action = '/api-token-auth/';
                    $response = wp_remote_post( $url . $action, array(
                            'method'  => 'POST',
                            'headers' => array('Content-Type' => 'application/json; charset=utf-8'),
                            'body'    => wp_json_encode(array(
                                'email' => $_POST['email'],
                                'password' => $_POST['password'],
                            )),
                        )
                    );
					break;
                case 'get_user_from_server':
					$action = '/get-user-database/';
                    $_monoedge_user_data = Monoedge_Utils::monoedge_get_all_data();
                    $_token = $_monoedge_user_data['api_token'];
                    if ( ! (isset( $_token ))) {
                        die( "api_token is not set." );
                    }
                    $response = wp_remote_post( $url . $action, array(
                            'method'  => 'POST',
                            'headers' => array(
                                'Authorization' => 'JWT ' . $_token,
                                'Content-Type' => 'application/json; charset=utf-8'),
                            'body'    => wp_json_encode(array()),
                        )
                    );                    
					break;
				case 'forgot_password':
					$action = '/user/password_reset/';  //////////////////////////////////
					break;
				default:
					$action = '/register/';  /////////////////////////////////////////
			};

			if ( is_wp_error( $response ) ) {
				$error_message = $response->get_error_message();
				die( "Something went wrong: " . esc_attr( $error_message ) );
			}

			return json_decode( $response[ 'body' ] , true);
		}

		public static function iframe_src( $section ) {
			$params = array( 'parent_window' => 'wordpress' );

			switch ( $section ) {
				case 'menu':
					$params[ 'r' ]                    = 'app.admin.setup.menu_app.menu_editor';
					$params[ 'hide_top_menu' ]        = 'true';
					$params[ 'hide_left_menu' ]       = 'true';
					$params[ 'hide_left_navigation' ] = 'true';
					break;

				case 'setup':
					$params[ 'r' ]              = 'app.admin_ftu.setup';
					$params[ 'hide_top_menu' ]  = 'true';
					$params[ 'hide_left_menu' ] = 'true';
					break;


				default:
					break;
			}

			$src = self::$_MONOEDGE->get_monoedge_token();
			$src .= strpos( $src, '?' ) ? '&' : '?1';

			foreach ( $params as $key => $value ) {
				$src .= "&$key=$value";
			}

			return $src;
		}

		public static function monoedge_get_all_data() {
			self::$_monoedge_user_data = get_option( 'monoedge_user_data' );
            if ( self::$_monoedge_user_data === false ) {
                return array();
            }
			return self::$_monoedge_user_data;
		}
		public static function monoedge_get_locations() {
            $all_data = self::monoedge_get_all_data();
            if ( isset($all_data) && isset($all_data['user']) ) {
                return ( isset( $all_data['user']['locations'] ) ?  $all_data['user']['locations'] : null);
            }
            return null;
		}
		public static function monoedge_get_user() {
            $all_data = self::monoedge_get_all_data();
            return ( isset( $all_data['user'] ) ?  $all_data['user'] : null);
		}        

        
		public static function monoedge_wp_options_data( $update = 'true' ) {
			if ( self::$_wp_options_data === null || $update === 'true' ) {
				self::$_wp_options_data = get_option( 'monoedge_wordpress_options' );
			}
            if ( self::$_wp_options_data === false ) {
                self::$_wp_options_data = new stdClass();
            } 

			return self::$_wp_options_data;
		}
		public static function monoedge_wp_options_data_get_option( $option_name,  $update = 'false' ) {

		    if ( self::$_wp_options_data === null || $update === 'true' ) {
				self::$_wp_options_data = get_option( 'monoedge_wordpress_options' );
			}

            $user_app_options = self::$_wp_options_data->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ];

			return ( isset( $user_app_options[ $option_name ] ) ? $user_app_options[ $option_name ] : '');
		}
		public static function get_location_data_by_location_uuid( $location_uuid ){
		    $locations = self::monoedge_get_locations();
		    $i = 0;
            if( $locations !== null ){
                foreach ( $locations as $location ) {
                    if ( isset( $location['location_uuid'] ) && $location['location_uuid'] === $location_uuid ) {
                        return $location;
                    }
                }
            }
		    return  '';
        }

		public static function monoedge_require_once( $file ) {
			if ( file_exists( $file ) ) {
				require_once $file;
			}
		}

		public static function monoedge_include( $file ) {
			if ( file_exists( $file ) ) {
				include $file;
			}
		}

		public static function monoedge_url_ends_with( $haystack, $needle ) {
			$length = strlen( $needle );
			if ( $length === 0 ) {
				return true;
			}

			return ( substr( $haystack, - $length ) === $needle );
		}

		public static function monoedge_get_shortcode( $location_uuid, $type, $useCustomCss = false, $class = "" ) {
			$code = '[';

			$code .= $type === 'reservations' ? 'restaurant-reservations' : 'restaurant-menu-and-ordering';
			$code .= ' location_uuid="' . $location_uuid . '"';

			if ( $useCustomCss ) {
				$code .= ' class="' . $class . '"';
			}

			$code .= ']';

			return $code;
		}

		public static function monoedge_set_default_app_options( $debug_reset = false, $source = '' ) {
		    if( !Monoedge_Utils::$_MONOEDGE->is_authenticated() && !$debug_reset ){
		        return;
            }
            $monoedge_wordpress_options = self::monoedge_wp_options_data();
            $per_user_default_options = array(
                'is_update' => false,
                'custom_css_by_location' => array(),
                'default_location' => '',
                'setup_options' => array(),
                // 'setup_options_status' => array(),
                'share_usage_data' => '',
                'partner_program' => ''
            );


            if ( !$monoedge_wordpress_options || $debug_reset ) {
                $monoedge_wordpress_options = new stdClass();
                if( $debug_reset ){
                    $monoedge_wordpress_options->custom_css_by_location = '';
                    self::monoedge_database_option_operation( 'update', 'monoedge_wordpress_options', $monoedge_wordpress_options );
                    return;
                }
            }
            if ( !isset( $monoedge_wordpress_options->{'app_options'} ) ) {
                $monoedge_wordpress_options->{'app_options'} = array();
            }
            if( !isset( $monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ] ) ){
                $monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ] = array();
            }

            /*
             * Update per user options.
             * This adds feature options on existing installed MonoEdge instances
             * */
            foreach ( $monoedge_wordpress_options->{'app_options'} as $key => &$user_app_options ){
                foreach ( $per_user_default_options as $default_option_name => $default_option_value ) {
                    if ( !isset( $user_app_options[ $default_option_name ] ) ) {
                        $user_app_options[ $default_option_name ] = $default_option_value;
                    }
                }
            }


            /*
             * Backward compatibility for versions before 2.0.0
             * Update the new app_options per user
             * */
            $is_update = $monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ][ 'is_update' ];
            if ( isset( $monoedge_wordpress_options->{'custom_css_by_location'} ) ) {
                $monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ][ 'custom_css_by_location' ] = $monoedge_wordpress_options->{'custom_css_by_location'};
                $is_update = true;
                //unset old stored value
                unset( $monoedge_wordpress_options->{'custom_css_by_location'} );
            }
            if ( isset( $monoedge_wordpress_options->{'default_location'} ) ) {
                $monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ][ 'default_location' ] = $monoedge_wordpress_options->{'default_location'};
                $is_update = true;
                //unset old stored value
                unset( $monoedge_wordpress_options->{'default_location'} );
            }
            $monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ][ 'is_update' ] = $is_update;
            self::monoedge_database_option_operation( 'update', 'monoedge_wordpress_options', $monoedge_wordpress_options );

            $setup_options = empty( Monoedge_Utils::monoedge_get_from_wordpress_options( 'setup_options', '' ) );
            $set_default_setup_options = $source === 'add_menu' && $is_update && $setup_options;
            if ( $set_default_setup_options ) {
                Monoedge_Helper_Screens::set_default_setup_options();
            }

        }

		public static function monoedge_custom_css_check_and_set_defaults( $default_css ) {
            $location_data_obj = self::monoedge_get_all_data();
            if ( !$location_data_obj || ( is_object( $location_data_obj ) && !isset( $location_data_obj->restaurants ) ) ) {
                return;
            }

            $monoedge_wordpress_options = self::monoedge_wp_options_data();
            $current_user_app_options = $monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ];

            if( !is_null( $location_data_obj->restaurants ) ){
                $update_location_custom_css = array();
                foreach ( $location_data_obj->restaurants as $location ) {
                    if ( !isset( $current_user_app_options[ 'custom_css_by_location' ][ $location['location_uuid'] ] ) ) {
                        $custom_css = $default_css;
                    } else {
                        $custom_css = $current_user_app_options[ 'custom_css_by_location' ][ $location['location_uuid']  ];
                    }
                    $update_location_custom_css[ $location['location_uuid']  ] = $custom_css;
                }
                $monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ][ 'custom_css_by_location' ] = $update_location_custom_css;
                update_option( 'monoedge_wordpress_options', $monoedge_wordpress_options );
            }
        }

		public static function monoedge_add_to_wordpress_options( $option_name, $option_value ){
            if ( Monoedge_Utils::$_MONOEDGE->is_authenticated() ) {
                $monoedge_wordpress_options = self::monoedge_wp_options_data();
                $monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ][ $option_name ] = $option_value;
                update_option( 'monoedge_wordpress_options', $monoedge_wordpress_options );
            }
        }
		public static function monoedge_get_from_wordpress_options( $option_name, $return_value, $update='true' ){
            if ( Monoedge_Utils::$_MONOEDGE->is_authenticated() ) {
                $monoedge_wordpress_options = self::monoedge_wp_options_data( $update );
                if ( ! (isset($monoedge_wordpress_options->{'app_options'}))) {
                    return $return_value;
                }
                if ( ! (isset($monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ]))) {
                    return $return_value;
                }
                if ( ! (isset($monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ][ $option_name] ))) {
                    return $return_value;
                }
                if( isset( $monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ][ $option_name] ) ){
                    $return_value = $monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ][ $option_name ];
                }
            }
            return $return_value;
        }

        /**
         *
         * Check if the user has already added an ordering button for a website domain
         *
         * @param string $current_done
         * @param object $location
         *
         * @return string
         */
		public static function monoedge_check_done_by_website_url( $current_done, $location ){
            $cur_site_url = get_site_url( null, '/' );
            // if ( !is_null( $location ) && in_array( get_site_url( null, '/' ), $location['location_url_name'], true )) {
            //     $current_done = 'true';
            // }
            return $current_done;

            $_location_url = get_site_url( null, '/' );
            if ( !is_null( $location ) && in_array( get_site_url( null, '/' ), $location['location_url_name'], true )) {
                $current_done = 'true';
            }
            return $current_done;
        }

		/**
		 *
		 * Get all locations or just one location custom_css
		 *
		 * @param string $location_uuid
		 *
		 * @return array|string|null
		 */
		public static function monoedge_get_locations_custom_css( $location_uuid = '' ) {
			$monoedge_wordpress_options = self::monoedge_wp_options_data();
			if ( ! $monoedge_wordpress_options ) {
				return null;
			}
            $location_uuid_custom_css = '';
            if ( Monoedge_Utils::$_MONOEDGE->is_authenticated() ) {
                $per_user_app_options = $monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ];

                $location_uuid_custom_css = ( isset( $per_user_app_options[ 'custom_css_by_location' ] ) ? $per_user_app_options[ 'custom_css_by_location' ] : '' );
                if ( is_array( $location_uuid_custom_css ) ) {
                    if ( ! empty( $location_uuid ) ) {
                        $location_uuid_custom_css = $location_uuid_custom_css[ $location_uuid ];
                    }
                }
            } else {
                // user has a lower version than 2.0.0 and was logged out at the time of the update
                // to version 2.0.2 - check for backward compatibility
                $monoedge_wordpress_options = self::monoedge_wp_options_data();
                if ( $monoedge_wordpress_options && isset( $monoedge_wordpress_options->{'custom_css_by_location'} ) ) {
                    $location_uuid_custom_css = $monoedge_wordpress_options->{'custom_css_by_location'};
                }
            }

			return $location_uuid_custom_css;
		}

		public static function get_all_locations_labels( $atts, $custom_css ) {
			$type                     = $atts[ 'type' ];
			$location                 = $atts[ 'ruid' ];
			$all_locations_custom_css = self::monoedge_get_locations_custom_css();
			if ( is_null( $all_locations_custom_css ) ) {
				self::monoedge_custom_css_check_and_set_defaults( $custom_css );
				$all_locations_custom_css = self::monoedge_get_locations_custom_css();
			}

			if ( is_array( $all_locations_custom_css ) ) {
				$labels = array( 'labels' => '', 'css' => '', 'customCSS' => '' );
				foreach ( $all_locations_custom_css as $location_uuid => $locations_custom_css ) {
					$label                 = ( $type === 'ordering' ? 'See MENU & Order' : 'Table Reservation' );
					$labels[ 'customCSS' ] = '';
					if ( isset ( $locations_custom_css[ $type ] ) ) {
						$label                 = $locations_custom_css[ $type ][ 'text' ];
						$labels[ 'customCSS' ] = self::get_custom_css_props_style( $locations_custom_css[ $type ] );
					}
					if ( isset( $atts[ 'class' ] ) ) {
						$labels_html = $label;
					} else {
						$labels_html = '<span class="monoedge-button-default monoedge-button ' . $atts[ 'extraCss' ] . '" style=\'' . $labels[ 'customCSS' ] . '\'  data-monoedge-cuid="" data-monoedge-ruid="' . $atts[ 'ruid' ] . '" ' . $atts[ 'extraAttr' ] . ' data-location="' . $location_uuid . '">' . $label . '</span>';
					}

					if ( empty( $location ) ) {
						$labels[ 'labels' ] .= $labels_html;
						$labels[ 'css' ]    .= ' .monoedge-' . $type . '-location' . '[data-location="' . $location_uuid . '"] > span[data-location="' . $location_uuid . '"]{ display:block; }';
					} else {
						if ( $location === $location_uuid ) {
							$labels[ 'labels' ] = $labels_html;
						}
					}
				}
			}

			return $labels;
		}

		/**
		 *
		 * Returns all custom css properties that exist.
		 *
		 * @param array|string|null $locations_custom_css
		 */
		public static function get_custom_css_props_style( $locations_custom_css ) {
			$customCSS = '';
			foreach ( $locations_custom_css as $key => $value ) {
				if ( $key !== 'text' && $key !== 'type' ) {
					$customCSS .= $key . ':' . $value . ( $key === 'color' ? ' !important; ' : '; ' );

				}
			}

			return $customCSS;
		}

		/**
		 *
		 * Set all locations or just one location custom_css
		 *
		 * @param array $custom_css
		 * @param string $location_uuid
		 */
		public static function monoedge_set_locations_custom_css( $custom_css, $location_uuid = '' ) {
			$monoedge_wordpress_options = self::monoedge_wp_options_data();
            $per_user_app_options = $monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ];
			if ( is_array( $custom_css ) ) {
				if ( ! empty( $location_uuid ) ) {
                    $per_user_app_options[ 'custom_css_by_location' ][ $location_uuid ] = $custom_css;
				} else {
                    $per_user_app_options[ 'custom_css_by_location' ] = $custom_css;
				}
			}
            $monoedge_wordpress_options->{'app_options'}[ self::$_MONOEDGE->user['user']['id'] ] = $per_user_app_options;
			update_option( 'monoedge_wordpress_options', $monoedge_wordpress_options );
		}

		public static function monoedge_get_locations_from_option() {
			$location_data_obj = self::monoedge_get_all_data();

			return isset( $location_data_obj->restaurants ) ? $location_data_obj->restaurants : null;
		}

		public static function monoedge_database_option_operation( $action, $option_name, $value = '' ) {
			$result = '';
			if ( $action === 'get' ) {
				$result = get_option( $option_name, false );
			} else {
				if ( $action === 'delete' ) {
					$result = delete_option( $option_name );
				} else {
					$action        = ( $action === 'update' && ! get_option( $option_name ) ) ? 'add' : $action;
					$function_name = $action . '_option';
					if ( function_exists( $function_name ) ) {
						$result = $function_name( $option_name, $value );
					}
				}
			}

			return $result;
		}

		// Sort restaurants and chains alphabetically by company_name.
		// Sort chain locations by name
		public static function monoedge_get_sorted_restaurants( $args = '' ) {
			$locations = empty( $args ) ? self::monoedge_get_locations() : $args;
            if ( !empty( $locations ) ) {
                usort( $locations, function ( $x, $y ) {
                    //compare all restaurants by company_name
                    $test = strtolower( $x['location_name'] ) > strtolower( $y['location_name'] );

                    $test = ($test ? 1 : -1);
                    return $test;
                } );
            }

			return $locations;
		}

		// output the select dropdown html for admin and publishing
		public static function monoedge_get_locations_dropdown( $id, $name, $property, $default_value, $onchange ) {
			?>
            <select name="<?php echo esc_attr( $name ); ?>" id="<?php echo esc_attr( $id ); ?>" onchange="<?php echo esc_attr( $onchange ); ?>()">
				<?php
				foreach ( self::monoedge_get_sorted_restaurants() as $location ) {
					$add_selected = '';
					if ( ! empty( $default_value ) && $default_value === $location['location_uuid'] ) {
						$add_selected = 'selected';
					}
					?>
                    <option value="<?php echo esc_attr( $location['location_uuid'] ); ?>" <?php echo esc_attr( $add_selected ); ?> data-uid="<?php echo esc_attr( $location['location_uuid'] ); ?>"><?php echo esc_attr( $location['location_name'] ); ?></option>
					<?php
				} ?>
            </select>
			<?php
		}

		// output the select dropdown html for admin and publishing
		public static function monoedge_get_locations_dropdown_elementor( $default_value = '' ) {
			$result = array(
				'default' => $default_value,
				'options' => array()
			);
			foreach ( self::monoedge_get_sorted_restaurants() as $location ) {
				if ( $default_value === '' ) {
					$result[ 'default' ] = $location['location_uuid'];
					$default_value       = $location['location_uuid'];
				}
				$result[ 'options' ][ $location['location_uuid'] ] = ( $location->is_chain ? '[' . ucwords( $location->company_name ) . '] ' : '' ) . $location->name;
			}

			return $result;
		}

        public static function group_same_schedule_type( $data ) {
            $grouped_data = array();
            //group by type
            foreach ( $data as $d ) {
                if ( !isset( $grouped_data[ $d->type ] ) ) {
                    $grouped_data[ $d->type ] = array();
                }
                $grouped_data[ $d->type ][] = $d;
            }
            // move Opening as first key
            // for the case when the date received doesn't have it as first key
            if ( isset( $grouped_data[ 'opening' ] ) ) {
                $opening = array( 'opening' => $grouped_data[ 'opening' ] );
                $grouped_data = array_reverse( $grouped_data );
                $grouped_data = array_merge( $opening, $grouped_data );
            }
            return $grouped_data;
        }

        public static function monoedge_check_if_classic_editor( $atts ){
            return (!isset( $atts[ 'gutenberg' ] ) && !isset( $atts[ 'elementor' ] ) );
        }

        public static function write_log( $data ) {
            if ( $data == null ) {
                error_log( print_r("null") );
                return;
            }
            if ( true === WP_DEBUG ) {
                if ( is_array( $data ) || is_object( $data ) ) {
                    error_log( print_r( $data, true ) );
                } else {
                    error_log( $data );
                }
            }
        }

        public static function monoedge_capabilities_check() {
            return (!(!empty( $_POST[ 'action' ] ) && current_user_can( 'manage_options' ) && isset( $_POST[ 'ajax_nonce' ] ) && wp_verify_nonce( $_POST[ 'ajax_nonce' ], 'monoedge-nonce' )));
        }

        public static function monoedge_capabilities_get_check() {
            return (!(!empty( $_GET[ 'action' ] ) && current_user_can( 'manage_options' ) && isset( $_GET[ 'ajax_nonce' ] ) && wp_verify_nonce( $_GET[ 'ajax_nonce' ], 'monoedge-nonce' )));
        }

        public static function monoedge_capabilities_check_failed( $response ) {
            $response[ 'status' ] = 'error';
            $response[ 'msg' ] = 'Access restricted, security check failed!';
            echo wp_json_encode( $response );
            exit();
        }

	}
}
